===========
 Changelog
===========

3.5 (2020-03-24)
================

- Prevent dates before 1900 from being entered as they cannot be rendered
  afterwards.

- Move source code repository to
  https://github.com/icemac/icemac.ab.calendar.


3.4 (2019-12-30)
================

- On mobile devices:

    + fix rendering of the calendar by replacing the tabular rendering by a
      vertical one like the print version.

    + replace secondary horizontal menu with a vertical one hidden behind a
      burger icon.

3.3 (2019-10-01)
================

- Consider customization of pre-defined fields in forms.

- Update the ZCML configuration and CSS to changes in
  `icemac.addressbook >= 9`.


Older versions
==============

See `OLD_CHANGES.rst`_.

.. _`OLD_CHANGES.rst` : https://github.com/icemac/icemac.ab.calendar/blob/master/OLD_CHANGES.rst
